@@ -1,135 +1,3 @@
-/*
- * $Date: 1995/04/08 22:30:40 $
- * $Source: /usr/src/dosemu0.60/dosemu/RCS/sigsegv.c,v $
- * $Revision: 2.20 $
- * $State: Exp $
- *
- * $Log: sigsegv.c,v $
- * Revision 2.20  1995/04/08  22:30:40  root
- * Release dosemu0.60.0
- *
- * Revision 2.20  1995/04/08  22:30:40  root
- * Release dosemu0.60.0
- *
- * Revision 2.19  1995/02/26  00:54:47  root
- * *** empty log message ***
- *
- * Revision 2.18  1995/02/25  22:37:52  root
- * *** empty log message ***
- *
- * Revision 2.17  1995/02/25  21:52:39  root
- * *** empty log message ***
- *
- * Revision 2.16  1995/02/05  16:52:03  root
- * Prep for Scotts patches.
- *
- * Revision 2.15  1995/01/14  15:29:17  root
- * New Year checkin.
- *
- * Revision 2.14  1994/11/03  11:43:26  root
- * Checkin Prior to Jochen's Latest.
- *
- * Revision 2.13  1994/10/14  17:58:38  root
- * Prep for pre53_27.tgz
- *
- * Revision 2.12  1994/10/03  00:24:25  root
- * Checkin prior to pre53_25.tgz
- *
- * Revision 2.11  1994/09/28  00:55:59  root
- * Prep for pre53_23.tgz
- *
- * Revision 2.10  1994/09/26  23:10:13  root
- * Prep for pre53_22.
- *
- * Revision 2.9  1994/09/23  01:29:36  root
- * Prep for pre53_21.
- *
- * Revision 2.8  1994/09/11  01:01:23  root
- * Prep for pre53_19.
- *
- * Revision 2.7  1994/08/14  02:52:04  root
- * Rain's latest CLEANUP and MOUSE for X additions.
- *
- * Revision 2.6  1994/08/05  22:29:31  root
- * Prep dir pre53_10.
- *
- * Revision 2.5  1994/08/01  14:26:23  root
- * Prep for pre53_7  with Markks latest, EMS patch, and Makefile changes.
- *
- * Revision 2.4  1994/07/09  14:29:43  root
- * prep for pre53_3.
- *
- * Revision 2.3  1994/06/27  02:15:58  root
- * Prep for pre53
- *
- * Revision 2.2  1994/06/24  14:51:06  root
- * Markks's patches plus.
- *
- * Revision 2.1  1994/06/12  23:15:37  root
- * Wrapping up prior to release of DOSEMU0.52.
- *
- * Revision 1.20  1994/06/03  00:58:55  root
- * pre51_23 prep, Daniel's fix for scrbuf malloc().
- *
- * Revision 1.19  1994/05/26  23:15:01  root
- * Prep. for pre51_21.
- *
- * Revision 1.18  1994/05/24  01:23:00  root
- * Lutz's latest, int_queue_run() update.
- *
- * Revision 1.17  1994/05/21  23:39:19  root
- * PRE51_19.TGZ with Lutz's latest updates.
- *
- * Revision 1.16  1994/05/16  23:13:23  root
- * Prep for pre51_16.
- *
- * Revision 1.15  1994/05/13  17:21:00  root
- * pre51_15.
- *
- * Revision 1.14  1994/05/10  23:08:10  root
- * pre51_14.
- *
- * Revision 1.13  1994/05/04  22:16:00  root
- * Patches by Alan to mouse subsystem.
- *
- * Revision 1.12  1994/05/04  21:56:55  root
- * Prior to Alan's mouse patches.
- *
- * Revision 1.11  1994/04/30  01:05:16  root
- * Clean Up.
- *
- * Revision 1.10  1994/04/27  23:39:57  root
- * Lutz's patches to get dosemu up under 1.1.9.
- *
- * Revision 1.9  1994/04/23  20:51:40  root
- * Get new stack over/underflow working in VM86 mode.
- *
- * Revision 1.8  1994/04/20  23:43:35  root
- * pre51_8 out the door.
- *
- * Revision 1.7  1994/04/18  20:57:34  root
- * Checkin prior to Jochen's latest patches.
- *
- * Revision 1.6  1994/04/16  01:28:47  root
- * Prep for pre51_6.
- *
- * Revision 1.5  1994/04/13  00:07:09  root
- * Lutz's patches
- *
- * Revision 1.4  1994/04/09  18:41:52  root
- * Prior to Lutz's kernel enhancements.
- *
- * Revision 1.3  1994/04/07  00:18:41  root
- * Pack up for pre52_4.
- *
- * Revision 1.2  1994/03/30  22:12:30  root
- * Prep for 0.51 pre 2.
- *
- * Revision 1.1  1994/03/24  22:40:31  root
- * Initial revision
- *
- */
-
 #include "config.h"
 
 #ifdef USE_MHPDBG
@@ -270,7 +138,7 @@ void print_exception_info(struct sigcontext_struct *scp);
  * DANG_BEGIN_FUNCTION dosemu_fault(int, struct sigcontext_struct);
  *
  * All CPU exceptions (except 13=general_protection from V86 mode,
- * which is directly scaned by the kernel) are handled here.
+ * which is directly scanned by the kernel) are handled here.
  *
  * DANG_END_FUNCTION
  */
@@ -301,6 +169,11 @@ int signal, int code, struct sigcontext *scp
       case 0x05: /* bounds */
       case 0x07: /* device_not_available */
 		 return (void) do_int(_trapno);
+
+      case 0x10: /* coprocessor error */
+		 pic_request(PIC_IRQ13); /* this is the 386 way of signalling this */
+		 return;
+
       case 0x06: /* invalid_op */
 		 dbug_printf("SIGILL while in vm86()\n");
 #if 0
@@ -636,6 +509,9 @@ void print_exception_info(struct sigcontext_struct *scp)
 	error("non-available page\n");
       break;
 
+   case 0x10:
+      error ("Coprocessor Error:\n");
+      break;
 
     default:
       error("Unknown exception\n");
