@@ -16,6 +16,7 @@ static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
 #include "termio.h"
 #include "machcompat.h"
 #include "vc.h"
+#include "../env/video/vga.h" /* NOTE: there exists also /usr/include/vga.h !! */
 #include "video.h"
 #include "mouse.h"
 #include "bios.h"
@@ -28,6 +29,7 @@ static char *id= "$Id: data.c,v 1.4 1995/04/08 22:29:37 root Exp $";
 #include "priv.h"
 #include "dma.h"
 #include "sound.h"
+#include "serial.h"
 #ifdef NEW_KBD_CODE
 #include "keyb_server.h"
 #include "keyb_clients.h"
