@@ -25,8 +25,13 @@
  *
  */
 
+#include <features.h>
 #include <sys/time.h>
+#if __GLIBC__ > 1
+#include <sys/kd.h>
+#else
 #include <linux/kd.h>
+#endif  
 #include "config.h"
 #include "emu.h"
 #include "port.h"
