@@ -27,9 +27,11 @@
 #define MAX_MEM_SIZE    640
 
 
+#if 0  /* initialized in data.c (via emu.h) */
 struct debug_flags d =
 {  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 /* d  R  W  D  C  v  X  k  i  T  s  m  #  p  g  c  w  h  I  E  x  M  n  P  r  S */
+#endif
 
 static void     check_for_env_autoexec_or_config(void);
 int     parse_debugflags(const char *s, unsigned char flag);
@@ -55,7 +57,8 @@ config_defaults(void)
     config.xms_size = 0;
     config.max_umb = 0;
     config.dpmi = 0;
-    config.secure = 0;
+    config.secure = 1;  /* need to have it 'on', else user may trick it out
+                           via -F option */
     config.mathco = 1;
     config.mouse_flag = 0;
     config.mapped_bios = 0;
@@ -140,6 +143,9 @@ config_defaults(void)
     config.detach = 0;		/* Don't detach from current tty and open
 				 * new VT. */
     config.debugout = NULL;	/* default to no debug output file */
+
+    config.pre_stroke =NULL;	/* defualt no keyboard pre-strokes */
+
     config.sillyint = 0;
     config.must_spare_hardware_ram = 0;
     memset(config.hardware_pages, 0, sizeof(config.hardware_pages));
@@ -171,9 +177,9 @@ config_defaults(void)
 static void 
 open_terminal_pipe(char *path)
 {
-    priv_off();
+    enter_priv_off();
     terminal_fd = DOS_SYSCALL(open(path, O_RDWR));
-    priv_default();
+    leave_priv_setting();
     if (terminal_fd == -1) {
 	terminal_pipe = 0;
 	error("ERROR: open_terminal_pipe failed - cannot open %s!\n", path);
@@ -219,11 +225,18 @@ open_Xmouse_pipe(char *path)
 void 
 config_init(int argc, char **argv)
 {
+    extern char *commandline_statements;
+    extern int dexe_running;
     int             c;
     char           *confname = NULL;
+    char           *basename;
+    char           *dexe_name = 0;
 
     config_defaults();
 
+    basename = strrchr(argv[0], '/');	/* parse the program name */
+    basename = basename ? basename + 1 : argv[0];
+
 #ifdef X_SUPPORT
     /*
      * DANG_BEGIN_REMARK For simpler support of X, DOSEMU can be started
@@ -231,11 +244,7 @@ config_init(int argc, char **argv)
      * into X-mode. DANG_END_REMARK
      */
     {
-	char           *p;
-	p = strrchr(argv[0], '/');	/* parse the program name */
-	p = p ? p + 1 : argv[0];
-
-	if (strcmp(p, "xdos") == 0)
+	if (strcmp(basename, "xdos") == 0)
 	    config.X = 1;	/* activate X mode if dosemu was */
 	/* called as 'xdos'              */
     }
@@ -243,14 +252,14 @@ config_init(int argc, char **argv)
 
     opterr = 0;
     confname = CONFIG_FILE;
-    while ((c = getopt(argc, argv, "ABCcF:kM:D:P:VNtsgx:Km234e:E:dXY:Z:o:O")) != EOF) {
+    while ((c = getopt(argc, argv, "ABCcF:I:kM:D:P:VNtsgx:KL:m234e:E:dXY:Z:o:Ou:")) != EOF) {
 	switch (c) {
 	case 'F':
-	    if (getuid()) {
+	    if (get_orig_uid()) {
 		FILE *f;
-		priv_off();
+		enter_priv_off();
 		f=fopen(optarg, "r");
-		priv_default();
+		leave_priv_setting();
 		if (!f) {
 		  fprintf(stderr, "Sorry, no access to configuration file %s\n", optarg);
 		  exit(1);
@@ -259,6 +268,12 @@ config_init(int argc, char **argv)
 	    }
 	    confname = optarg;	/* someone reassure me that this is *safe*? */
 	    break;
+	case 'L':
+	    dexe_name = optarg;
+	    break;
+	case 'I':
+	    commandline_statements = optarg;
+	    break;
 	case 'd':
 	    if (config.detach)
 		break;
@@ -273,17 +288,35 @@ config_init(int argc, char **argv)
 	    break;
 	case 'o':
 	    config.debugout = strdup(optarg);
-	    priv_off();
+	    enter_priv_off();
 	    dbg_fd = fopen(config.debugout, "w");
-	    priv_default();
+	    leave_priv_setting();
 	    if (!dbg_fd) {
 		fprintf(stderr, "can't open \"%s\" for writing\n", config.debugout);
 		exit(1);
 	    }
 	    break;
+	case 'u': {
+		extern int define_config_variable(char *name);
+		char *s=malloc(strlen(optarg)+3);
+		s[0]='u'; s[1]='_';
+		strcpy(s+2,optarg);
+		define_config_variable(s);
+	    }
+	    break;
 	}
     }
 
+    if (dexe_name || !strcmp(basename,"dosexec")) {
+	extern void prepare_dexe_load(char *name);
+	if (!dexe_name) dexe_name = argv[optind];
+	if (!dexe_name) {
+	  usage();
+	  exit(1);
+	}
+	prepare_dexe_load(dexe_name);
+    }
+
 #if defined(__NetBSD__) && defined(X_SUPPORT) && defined(X_GRAPHICS)
     { extern int selfmem_fd;
     /* do this before any set*id functions are called */
@@ -304,18 +337,21 @@ config_init(int argc, char **argv)
     optind = 0;
 #endif
     opterr = 0;
-    while ((c = getopt(argc, argv, "ABCcF:kM:D:P:v:VNtT:sgx:Km2345e:dXY:Z:E:o:O")) != EOF) {
+    while ((c = getopt(argc, argv, "ABCcF:I:kM:D:P:v:VNtT:sgx:KLm2345e:dXY:Z:E:o:Ou:")) != EOF) {
 	switch (c) {
 	case 'F':		/* previously parsed config file argument */
+	case 'I':
 	case 'd':
 	case 'o':
 	case 'O':
+	case 'L':
+	case 'u':
 	    break;
 	case 'A':
-	    config.hdiskboot = 0;
+	    if (!dexe_running) config.hdiskboot = 0;
 	    break;
 	case 'B':
-	    config.hdiskboot = 2;
+	    if (!dexe_running) config.hdiskboot = 2;
 	    break;
 	case 'C':
 	    config.hdiskboot = 1;
@@ -461,9 +497,24 @@ config_init(int argc, char **argv)
 	}
     }
     if (config.X) {
+	if (!config.X_keycode) {
+	    extern void keyb_layout(int layout);
+	    keyb_layout(-1);
+	    c_printf("CONF: Forceing neutral Keyboard-layout, X-server will translate\n");
+	}
 	config.console_video = config.vga = config.graphics = 0;
     }
     check_for_env_autoexec_or_config();
+    if (under_root_login)  c_printf("CONF: running exclusively as ROOT:");
+    else {
+#ifdef RUN_AS_ROOT
+      c_printf("CONF: mostly running as ROOT:");
+#else
+      c_printf("CONF: mostly running as USER:");
+#endif
+    }
+    c_printf(" uid=%d (cached %d) gid=%d (cached %d)\n",
+        geteuid(), get_cur_euid(), getegid(), get_cur_egid());
 }
 
 
@@ -647,7 +698,7 @@ static void
 usage(void)
 {
     fprintf(stdout, "dosemu 0.66\n");
-    fprintf(stdout, "usage: dos [-ABCckbVNtsgxKm234e] [-D flags] [-M SIZE] [-P FILE] [ -F File ] 2> dosdbg\n");
+    fprintf(stdout, "USAGE:\n dos [-ABCckbVNtsgxKm234e] [-D flags] [-M SIZE] [-P FILE] [ {-F|-L} File ] 2> dosdbg\n");
     fprintf(stdout, "    -2,3,4,5 choose 286, 386, 486 or 586 CPU\n");
     fprintf(stdout, "    -A boot from first defined floppy disk (A)\n");
     fprintf(stdout, "    -B boot from second defined floppy disk (B) (#)\n");
@@ -672,6 +723,8 @@ usage(void)
     fprintf(stdout, "    -E STRING pass DOS command on command line\n");
     fprintf(stdout, "    -e SIZE enable SIZE K EMS RAM\n");
     fprintf(stdout, "    -F use config-file File\n");
+    fprintf(stdout, "    -L load and execute DEXE File\n");
+    fprintf(stdout, "    -I insert config statements (on commandline)\n");
     fprintf(stdout, "    -g enable graphics modes (!%%#)\n");
     fprintf(stdout, "    -K Do int9 (!#)\n");
     fprintf(stdout, "    -k use PC console keyboard (!)\n");
@@ -688,5 +741,7 @@ usage(void)
     fprintf(stdout, "    -x SIZE enable SIZE K XMS RAM\n");
     fprintf(stdout, "    (!) BE CAREFUL! READ THE DOCS FIRST!\n");
     fprintf(stdout, "    (%%) require dos be run as root (i.e. suid)\n");
-    fprintf(stdout, "    (#) options do not fully work yet\n");
+    fprintf(stdout, "    (#) options do not fully work yet\n\n");
+    fprintf(stdout, "xdos [options]           == dos [options] -X\n");
+    fprintf(stdout, "dosexec [options] <file> == dos [options] -L <file>\n");
 }
