@@ -1,3 +1,4 @@
+#include <features.h>
 #include <stdio.h>
 #include <string.h>
 #include <termios.h>
@@ -12,9 +13,15 @@
 #include <errno.h>
 
 #ifdef __linux__
+#if __GLIBC__ > 1
+#include <sys/utsname.h>
+#define new_utsname utsname
+#else
 #include <linux/config.h>
 #include <linux/utsname.h>
-#endif
+#endif /* __GLIBC__ */
+#endif /* __linux__ */
+
 #ifdef __NetBSD__
 #include <sys/utsname.h>
 #define new_utsname utsname
@@ -45,6 +52,7 @@
 #include "shared.h"
 #include "iodev.h"
 #include "priv.h"
+#include "doshelpers.h"
 
 #ifdef NEW_KBD_CODE
 #include "keyb_clients.h"
@@ -140,9 +148,9 @@ void stdio_init(void)
 void tmpdir_init(void)
 {
   /* create tmpdir */
-  priv_off();
+  enter_priv_off();
   mkdir(tmpdir, S_IREAD | S_IWRITE | S_IEXEC);
-  priv_default();
+  leave_priv_setting();
 }
 
 /*
@@ -331,8 +339,8 @@ static inline void map_custom_bios(void)
   *ptr++ = 0xb8;                /* mov ax, 0xffff */
   *ptr++ = 0xff;
   *ptr++ = 0xff;
-  *ptr++ = 0xcd;                /* int 0xe6 */
-  *ptr++ = 0xe6;
+  *ptr++ = 0xcd;                /* int DOS_HELPER_INT(0xe6) */
+  *ptr++ = DOS_HELPER_INT;
 
 #if 0 /* for debugging only */
   f = fopen("/tmp/bios","w");
