@@ -1142,6 +1142,150 @@ CONST unsigned char alt_map_sw[] =
   0, 0, 0, 0, 0, 0, 0, 0,
   0};
 
+CONST unsigned char key_map_hu[] =
+{
+  0, 27, '1', '2', '3', '4', '5', '6',
+  '7', '8', '9', 148, 129, 162, 127, 9,
+  'q', 'w', 'e', 'r', 't', 'z', 'u', 'i',
+  'o', 'p', 139, 163, 13, 0, 'a', 's',
+  'd', 'f', 'g', 'h', 'j', 'k', 'l', 130,
+  160, '0', 0, 251, 'y', 'x', 'c', 'v',
+  'b', 'n', 'm', ',', '.', '-', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 161, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char shift_map_hu[] =
+{
+  0, 27, '\'', '"', '+', '!', '%', '/',
+  '=', '(', ')', 153, 154, '\'O', 127, 9,
+  'Q', 'W', 'E', 'R', 'T', 'Z', 'U', 'I',
+  'O', 'P', 138, 233, 13, 0, 'A', 'S',
+  'D', 'F', 'G', 'H', 'J', 'K', 'L', 144,
+  181, 21, '0', 235, 'Y', 'X', 'C', 'V',
+  'B', 'N', 'M', '?', ':', '_', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 146, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char alt_map_hu[] =
+{
+  0, 0, '~', 0, '^', 0, 0, 0,
+  '`', 0, 0, 0, 0, 0, 0, 0,
+  '\\', '|', 0, 0, 0, 0, 0, 146,
+  0, 0, 246, 158, 13, 0, 0, 208,
+  209, '[', ']', 0, 161, 136, 157, '$',
+  225, 0, 0, 207, '>', '#', '&', '@',
+  '{', '}', 0, ';', 0, '*', 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, '<', 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char key_map_hu_cwi[] =
+{
+  0, 27, '1', '2', '3', '4', '5', '6',
+  '7', '8', '9', 148, 129, 162, 127, 9,
+  'q', 'w', 'e', 'r', 't', 'z', 'u', 'i',
+  'o', 'p', 147, 163, 13, 0, 'a', 's',
+  'd', 'f', 'g', 'h', 'j', 'k', 'l', 130,
+  160, '0', 0, 150, 'y', 'x', 'c', 'v',
+  'b', 'n', 'm', ',', '.', '-', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 161, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char shift_map_hu_cwi[] =
+{
+  0, 27, '\'', '"', '+', '!', '%', '/',
+  '=', '(', ')', 153, 154, 149, 127, 9,
+  'Q', 'W', 'E', 'R', 'T', 'Z', 'U', 'I',
+  'O', 'P', 167, 151, 13, 0, 'A', 'S',
+  'D', 'F', 'G', 'H', 'J', 'K', 'L', 144,
+  143, 21, '0', 152, 'Y', 'X', 'C', 'V',
+  'B', 'N', 'M', '?', ':', '_', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 141, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char alt_map_hu_cwi[] =
+{
+  0, 0, '~', 0, '^', 0, 0, 0,
+  '`', 0, 0, 0, 0, 0, 0, 0,
+  '\\', '|', 0, 0, 0, 0, 0, 141,
+  0, 0, 246, 0, 13, 0, 0, 0,
+  0, '[', ']', 0, 161, 0, 0, '$',
+  225, 0, 0, 0, '>', '#', '&', '@',
+  '{', '}', 0, ';', 0, '*', 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, '<', 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char key_map_hu_latin2[] =
+{
+  0, 27, '1', '2', '3', '4', '5', '6',
+  '7', '8', '9', 246, 252, 243, 127, 9,
+  'q', 'w', 'e', 'r', 't', 'z', 'u', 'i',
+  'o', 'p', 245, 250, 13, 0, 'a', 's',
+  'd', 'f', 'g', 'h', 'j', 'k', 'l', 233,
+  225, '0', 0, 251, 'y', 'x', 'c', 'v',
+  'b', 'n', 'm', ',', '.', '-', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 237, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char shift_map_hu_latin2[] =
+{
+  0, 27, '\'', '"', '+', '!', '%', '/',
+  '=', '(', ')', 214, 220, 211, 127, 9,
+  'Q', 'W', 'E', 'R', 'T', 'Z', 'U', 'I',
+  'O', 'P', 213, 218, 13, 0, 'A', 'S',
+  'D', 'F', 'G', 'H', 'J', 'K', 'L', 201,
+  193, 21, '0', 219, 'Y', 'X', 'C', 'V',
+  'B', 'N', 'M', '?', ':', '_', 0, '*',
+  0, 32, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, '-', 0, 0, 0, '+', 0,
+  0, 0, 0, 0, 0, 0, 205, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
+CONST unsigned char alt_map_hu_latin2[] =
+{
+  0, 0, '~', 0, '^', 0, 0, 0,
+  '`', 0, 0, 0, 0, 0, 0, 0,
+  '\\', '|', 0, 0, 0, 0, 0, 205,
+  0, 0, 247, 215, 13, 0, 0, 240,
+  208, '[', ']', 0, 237, 179, 163, '$',
+  223, 0, 0, 164, '>', '#', '&', '@',
+  '{', '}', 0, ';', 0, '*', 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0, 0, 0, 0, 0, 0, '<', 0,
+  0, 0, 0, 0, 0, 0, 0, 0,
+  0};
+
 CONST unsigned char num_table_dot[]   = "789-456+1230.";
 CONST unsigned char num_table_comma[] = "789-456+1230,";
 
