@@ -291,7 +291,8 @@ image_auto(struct disk *dp)
     leavedos(19);
   }
 
-  if (strncmp(header, IMAGE_MAGIC, IMAGE_MAGIC_SIZE)) {
+  if (strncmp(header, IMAGE_MAGIC, IMAGE_MAGIC_SIZE)
+		&& (*((long *)header) != DEXE_MAGIC) ) {
     error("ERROR: IMAGE %s header lacks magic string - cannot autosense!\n",
 	  dp->dev_name);
     leavedos(20);
@@ -802,8 +803,14 @@ disk_init(void)
   }
   for (dp = hdisktab; dp < &hdisktab[HDISKS]; dp++) {
     if(dp->type == IMAGE)  {
-	d_printf("IMAGE: Using user permissions\n");
-	enter_priv_off();
+	if (dp->dexeflags & DISK_DEXE_RDWR) {
+	  d_printf("IMAGE: dexe, RDWR access allowed for %s\n",dp->dev_name);
+	  enter_priv_on();
+	}
+	else {
+	  d_printf("IMAGE: Using user permissions\n");
+	  enter_priv_off();
+	}
     }
     else enter_priv_on();
     dp->fdesc = open(dp->dev_name, dp->rdonly ? O_RDONLY : O_RDWR, 0);
@@ -1146,7 +1153,7 @@ int13(u_char i)
       HI(cx) = (dp->tracks - 1) & 0xff;
 
       LO(dx) = (disk < 0x80) ? FDISKS : HDISKS;
-      LO(cx) = dp->sectors | ((dp->tracks & 0x300) >> 2);
+      LO(cx) = dp->sectors | (((dp->tracks -1) & 0x300) >> 2);
       LO(ax) = 0;
       HI(ax) = DERR_NOERR;
       REG(eflags) &= ~CF;	/* no error */
