@@ -11,7 +11,7 @@
                         gettimeofday(&tv,NULL);\
                         fprintf(stderr,"%c %06d:%06d\n",x,(int)tv.tv_sec,(int)tv.tv_usec);\
                    }
-
+#include <features.h>
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/shm.h>
@@ -20,8 +20,12 @@
 #include <sys/socket.h>
 #include <sys/ioctl.h>
 #ifndef __NetBSD__
+#if __GLIBC__ > 1
+#include <netinet/if_ether.h>
+#else
 #include <linux/if_ether.h>
 #endif
+#endif
 #include <signal.h>
 #include <stdlib.h>
 #include <fcntl.h>
@@ -32,6 +36,10 @@
 #include <string.h>
 #include <termios.h>			/* for mouse.h */
 #ifdef __NetBSD__
+#include <features.h>
+#endif
+#if __GLIBC__ > 1
+#include <features.h>
 #include <sys/mman.h>
 #else
 #define MAP_ANON MAP_ANONYMOUS
@@ -92,18 +100,18 @@ void HMA_MAP(int HMA)
   int retval;
 
   E_printf("Entering HMA_MAP with HMA=%d\n", HMA);
-  priv_on();
+  enter_priv_on();
   retval = shmdt(HMAAREA);
-  priv_default();
+  leave_priv_setting();
   if (retval < 0) {
     E_printf("HMA: Detaching HMAAREA unsuccessful: %s\n", strerror(errno));
     leavedos(48);
   }
   E_printf("HMA: detached at %p\n", HMAAREA);
   if (HMA){
-    priv_on();
+    enter_priv_on();
     ipc_return = (caddr_t) shmat(shm_hma_id, HMAAREA, SHM_REMAP );
-    priv_default();
+    leave_priv_setting();
     if (ipc_return == (caddr_t) 0xffffffff) {
       E_printf("HMA: Mapping HMA id %x to HMAAREA %p unsuccessful: %s\n",
 	       shm_hma_id, HMAAREA, strerror(errno));
@@ -112,9 +120,9 @@ void HMA_MAP(int HMA)
     E_printf("HMA: mapped id %x to %p\n", shm_hma_id, ipc_return);
   }
   else {
-    priv_on();
+    enter_priv_on();
     ipc_return = (caddr_t) shmat(shm_wrap_id, HMAAREA, 0 );
-    priv_default();
+    leave_priv_setting();
     if (ipc_return == (caddr_t) 0xffffffff) {
       E_printf("HMA: Mapping WRAP to HMAAREA unsuccessful: %s\n", strerror(errno));
       leavedos(47);
