@@ -113,9 +113,9 @@ E_printf("SHM: Client request area set to %04d\n", *(int *)(shared_qf_memory + C
   pid = getpid();
   sprintf(devname_, "%s%d", TMPFILE, pid);
 
-  priv_on();
+  enter_priv_on();
   tmpfile_fd = open(devname_, O_WRONLY|O_CREAT, 0666);
-  priv_default();
+  leave_priv_setting();
   if (tmpfile_fd < 1) {
     E_printf("SHM: Unable to open %s%d for sending client data: %s\n",TMPFILE, pid, strerror(errno));
   }
@@ -133,9 +133,9 @@ E_printf("SHM: Client request area set to %04d\n", *(int *)(shared_qf_memory + C
 void shared_memory_exit(void) {
 
 #if 1
-  priv_on();
+  enter_priv_on();
   unlink(devname_);
-  priv_default();
+  leave_priv_setting();
 #endif
 
 }
