@@ -20,12 +20,11 @@
  *      ag115@freenet.carleton.ca
  *
  * maintainer:
- * Mark Rejhon <markg@magmacom.com>
- * Mark Rejhon <ag115@freenet.carleton.ca>
+ * Mark Rejhon <marky@ottawa.com>
  *
  * DANG_END_MODULE
  */
-
+#include <features.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -38,7 +37,11 @@
 #include <sys/stat.h>
 #include <errno.h>
 #ifdef __linux__
+#ifndef __GLIBC__
 #include <linux/fs.h>
+#else
+#include <limits.h>
+#endif
 #endif
 #include <pwd.h>
 #ifdef __NetBSD__
@@ -58,7 +61,9 @@
 /* See README.serial file for more information on the com[] structure 
  * The declarations for this is in ../include/serial.h
  */
+#if 0
 serial_t com[MAX_SER];
+#endif
 
 /*  Determines if the tty is already locked.  Stolen from uri-dip-3.3.7k
  *  Nice work Uri Blumenthal & Ian Lance Taylor!
@@ -109,7 +114,7 @@ static int tty_lock(char *path, int mode)
   int cwrote;
 
   /* Check that lockfiles can be created! */
-  if((mode == 1 || mode == 2) && geteuid() != (uid_t)0) {
+  if((mode == 1 || mode == 2) && get_orig_euid() != (uid_t)0) {
     s_printf("DOSEMU: Need to be suid root to create Lock Files!\n"
 	     "        Serial port on %s not configured!\n", path);
     error("\nDOSEMU: Need to be suid root to create Lock Files!\n"
@@ -131,9 +136,9 @@ static int tty_lock(char *path, int mode)
         error("\nDOSEMU: attempt to use already locked tty %s\n", saved_path);
         return (-1);
       }
-      priv_on();
+      enter_priv_on();
       fd = fopen(saved_path, "w");
-      priv_default();
+      leave_priv_setting();
       if (fd == (FILE *)0) {
         s_printf("DOSEMU: lock: (%s): %s\n", saved_path, strerror(errno));
         error("\nDOSEMU: tty: lock: (%s): %s\n", saved_path, strerror(errno));
@@ -161,9 +166,9 @@ static int tty_lock(char *path, int mode)
   else if (mode == 2) { /* re-acquire a lock after a fork() */
     FILE *fd;
 
-     priv_on();
+     enter_priv_on();
      fd = fopen(saved_path,"w");
-     priv_default();
+     leave_priv_setting();
      if (fd == (FILE *)0) {
      s_printf("DOSEMU: tty_lock(%s) reaquire: %s\n", 
               saved_path, strerror(errno));
@@ -180,25 +185,25 @@ static int tty_lock(char *path, int mode)
 
     (void) fclose(fd);
     (void) chmod(saved_path, 0444);
-    (void) chown(saved_path, getuid(), getgid());
+    (void) chown(saved_path, get_orig_uid(), get_orig_gid());
     return(0);
   } 
   else {    /* unlock */
     FILE *fd;
     int retval;
 
-    priv_on();
+    enter_priv_on();
     fd = fopen(saved_path,"w");
-    priv_default();
+    leave_priv_setting();
     if (fd == (FILE *)0) {
       s_printf("DOSEMU: tty_lock: can't reopen to delete: %s\n",
              strerror(errno));
       return (-1);
     }
       
-    priv_on();
+    enter_priv_on();
     retval = unlink(saved_path);
-    priv_off();
+    leave_priv_setting();
     if (retval < 0) {
       s_printf("DOSEMU: tty: unlock: (%s): %s\n", saved_path,
              strerror(errno));
