@@ -785,11 +785,13 @@ mfs_redirector(void)
   int ret;
 
   PS(MFS);
-  if (!priv_off())
+  if (!enter_priv_off()) {
+    leave_priv_setting();
     return 0;
+  }
 
   ret = dos_fs_redirect(&REGS);
-  priv_default();
+  leave_priv_setting();
   PE(MFS);
 
   Debug0((dbg_fd, "Finished dos_fs_redirect\n"));
@@ -818,11 +820,12 @@ mfs_inte6(void)
   boolean_t dos_fs_dev();
   boolean_t result;
 
-  if (!priv_off())
+  if (!enter_priv_off()) {
+    leave_priv_setting();
     return 0;
-
+  }
   result = dos_fs_dev(&REGS);
-  priv_default();
+  leave_priv_setting();
   return (result);
 }
 
@@ -2650,24 +2653,21 @@ dos_fs_redirect(state)
 	  /* return unit = 512-byte blocks @ 1 spc, std for floppy */
 	  int spc = 1;
 	  int bps = 512;
-	  unsigned long tmpf, tmpt;
 
-	  if ((tot > 65535) || (free > 65535)) {
+	  while ((spc<32) && ((tot > 65535) || (free > 65535))) {
 	    /* we're on an HD here! */
-	    bps = 1024;
-	    free /= 2;			/* try 1024-byte sectors */
-	    tot  /= 2;
-
-	    while ((tot > 65535) || (free > 65535)) {
-	      tmpf = free * spc;
-	      tmpt = tot  * spc;
-
-	      spc <<= 1;		/* try bigger clusters */
-
-	      free = tmpf / spc;
-	      tot =  tmpt / spc;
+	    if (bps==512) {
+	      bps = 1024;	/* try 1024-byte sectors first */
 	    }
+	    else
+	      spc *= 2;		/* try bigger clusters, up to 32 */
+	    free /= 2;
+	    tot  /= 2;
 	  }
+	  /* report no more than 32*1024*64K = 2G, even if some
+	     DOS version 7 can see more */
+	  if (tot>65535) tot=65535;
+	  if (free>65535) free=65535;
 
 	  /* Ralf Brown says: AH=media ID byte - can we let it at 0 here? */
 	  SETWORD(&(state->eax), spc);
@@ -3033,7 +3033,11 @@ dos_fs_redirect(state)
     if (FCBcall)
       sft_open_mode(sft) |= 0x00f0;
     else
-      sft_open_mode(sft) = 0x3;
+  #if 0
+      sft_open_mode(sft) = 0x3; /* write only */
+  #else
+      sft_open_mode(sft) = 0x2; /* read/write */
+  #endif
 #endif
     sft_directory_entry(sft) = 0;
     sft_directory_sector(sft) = 0;
