@@ -30,6 +30,7 @@
 #include "emu.h"
 #include "cpu.h"
 #include "inifile.h"
+#include "doshelpers.h"
 
 #define MAX_PACKET_DATA		1500
 
@@ -172,8 +173,8 @@ InitIPXFarCallHelper(void)
   *ptr++ = 0x50;		/* push ax - FarCallHandler removes this before returning */
   *ptr++ = 0xb0;		/* mov al, 7a */
   *ptr++ = 0x7a;
-  *ptr++ = 0xcd;		/* int 0xe6 */
-  *ptr++ = 0xe6;
+  *ptr++ = 0xcd;		/* int DOS_HELPER_INT (0xe6) */
+  *ptr++ = DOS_HELPER_INT;
   *ptr++ = 0xcb;		/* far ret */
 
   ESRPopRegistersReturn.segment = ((int) ptr) >> 4;
@@ -434,23 +435,39 @@ IPXOpenSocket(u_short port, u_short * newPort)
   opt = 1;
   /* turn on socket debugging */
   if (d.network) {
+    enter_priv_on();
     if (setsockopt(sock, SOL_SOCKET, SO_DEBUG, &opt, sizeof(opt)) == -1) {
+      leave_priv_setting();
       n_printf("IPX: could not set socket option for debugging.\n");
       /* I can't think of anything else to return */
       return (RCODE_SOCKET_TABLE_FULL);
     }
+    leave_priv_setting();
   }
   opt = 1;
   /* Permit broadcast output */
+  enter_priv_on();
   if (setsockopt(sock, SOL_SOCKET, SO_BROADCAST,
 		 &opt, sizeof(opt)) == -1) {
+    leave_priv_setting();
     /* I can't think of anything else to return */
     n_printf("IPX: could not set socket option for broadcast.\n");
     return (RCODE_SOCKET_TABLE_FULL);
   }
   /* allow setting the type field in the IPX header */
   opt = 1;
+#if 0 /* this seems to be wrong: IPX_TYPE can only be set on level SOL_IPX */
   if (setsockopt(sock, SOL_SOCKET, IPX_TYPE, &opt, sizeof(opt)) == -1) {
+#else
+  /* the socket _is_ an IPX socket, hence it first passes ipx_setsockopt()
+   * in file linux/net/ipx/af_ipx.c. This one handles SOL_IPX itself and
+   * passes SOL_SOCKET-levels down to sock_setsockopt().
+   * Hence I guess the below is correct (can somebody please verify this?)
+   * -- Hans, June 14 1997
+   */
+  if (setsockopt(sock, SOL_IPX, IPX_TYPE, &opt, sizeof(opt)) == -1) {
+#endif
+    leave_priv_setting();
     /* I can't think of anything else to return */
     n_printf("IPX: could not set socket option for type.\n");
     return (RCODE_SOCKET_TABLE_FULL);
@@ -466,6 +483,7 @@ IPXOpenSocket(u_short port, u_short * newPort)
     /* I can't think of anything else to return */
     n_printf("IPX: could not bind socket to address\n");
     close( sock );
+    leave_priv_setting();
     return (RCODE_SOCKET_TABLE_FULL);
   }
   
@@ -475,12 +493,14 @@ IPXOpenSocket(u_short port, u_short * newPort)
       /* I can't think of anything else to return */
       n_printf("IPX: could not get socket name in IPXOpenSocket\n");
       close( sock );
+      leave_priv_setting();
       return(RCODE_SOCKET_TABLE_FULL);
     } else {
       port = htons(ipxs2.sipx_port);
       n_printf("IPX: opened dynamic socket %04x\n", port);
     }
   }
+  leave_priv_setting();
   
   /* if we successfully bound to this port, then record it */
   ipx_insert_socket(port, /* PSP */ 0, sock);
