@@ -34,7 +34,8 @@
 #include "vc.h"
 #include "vga.h"
 #include "s3.h"
-
+#include "priv.h"
+ 
 static int s3_chip = 0;
 static int s3_chiprev = 0;
 static int s3_memsize = 0;
@@ -228,12 +229,12 @@ static void s3_save_ext_regs(u_char xregs[], u_short xregs16[])
 
 	xregs[2] = port_in(0x102);
 	port_out(1, 0x102);
-	iopl(3);
+	priv_iopl(3);
 	xregs16[0] = port_in_w(0x8000 | s3_8514_base);	/* CUR_Y */
 	xregs16[1] = port_in_w(0x8400 | s3_8514_base);	/* CUR_X */
 	xregs16[2] = port_in_w(0x8800 | s3_8514_base);
 	xregs16[3] = port_in_w(0x8c00 | s3_8514_base);
-	iopl(0);
+	priv_iopl(0);
 	port_out(xregs[2], 0x102);
 
 }
@@ -303,12 +304,12 @@ static void s3_restore_ext_regs(u_char xregs[], u_short xregs16[])
 	out_crt(0x39, xregs[1]);
 
 	port_out(1, 0x102);
-	iopl(3);
+	priv_iopl(3);
 	port_out_w(xregs16[0], 0x8000 | s3_8514_base);
 	port_out_w(xregs16[1], 0x8400 | s3_8514_base);
 	port_out_w(xregs16[2], 0x8800 | s3_8514_base);
 	port_out_w(xregs16[3], 0x8c00 | s3_8514_base);
-	iopl(0);
+	priv_iopl(0);
 	port_out(xregs[2], 0x102);
 }
 
