@@ -19,7 +19,7 @@
  *
  */
 
-
+#include <features.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <sys/ioctl.h>
@@ -34,18 +34,27 @@
 #include <sys/mman.h>
 #endif
 #ifdef __linux__
+#ifndef __GLIBC__
 #define MAP_ANON MAP_ANONYMOUS
 extern caddr_t mmap __P ((caddr_t __addr, size_t __len,
 			  int __prot, int __flags, int __fd, off_t __off));
 extern int munmap __P ((caddr_t __addr, size_t __len));
 #include <linux/mman.h>
+#else
+#include <sys/mman.h>
+#endif
 #endif
 #include <signal.h>
 #include <sys/stat.h>
 #ifdef __linux__
+#if __GLIBC__ > 1
+#include <sys/vt.h>
+#include <sys/kd.h>
+#else
 #include <linux/vt.h>
 #include <linux/kd.h>
 #endif
+#endif
 #ifdef __NetBSD__
 #include <machine/pcvt_ioctl.h>
 #endif
@@ -194,9 +203,9 @@ parent_open_mouse (void)
 {
   if (mice->intdrv)
     {
-      priv_on(); /* The mouse may not be a resource everyone can open. */
+      enter_priv_on(); /* The mouse may not be a resource everyone can open. */
       mice->fd = DOS_SYSCALL (open (mice->dev, O_RDWR | O_NONBLOCK));
-      priv_default();
+      leave_priv_setting();
       if (mice->fd > 0)
 	add_to_io_select(mice->fd, mice->add_to_io_select);
     }
@@ -617,9 +626,9 @@ clear_process_control (void)
   struct vt_mode vt_mode;
 
   vt_mode.mode = VT_AUTO;
-  priv_on();
+  enter_priv_on();
   ioctl (console_fd, VT_SETMODE, (int) &vt_mode);
-  priv_default();
+  leave_priv_setting();
   signal (SIG_RELEASE, SIG_IGN);
   signal (SIG_ACQUIRE, SIG_IGN);
 }
@@ -646,9 +655,9 @@ open_kmem (void)
 
   if (mem_fd != -1)
     return;
-  priv_on();
+  enter_priv_on();
   mem_fd = open("/dev/mem", O_RDWR);
-  priv_default();
+  leave_priv_setting();
   if (mem_fd < 0)
     {
       error ("ERROR: can't open /dev/mem: errno=%d, %s \n",
@@ -1200,7 +1209,7 @@ install_int_10_handler (void)
       *ptr++ = 0x08;		/* mov  al,08  ; Start Video init     */
 
       *ptr++ = 0xcd;
-      *ptr++ = 0xe6;		/* int  e6          */
+      *ptr++ = DOS_HELPER_INT;		/* int  e6          */
 
       if (config.vbios_seg == 0xe000)
 	{
@@ -1222,7 +1231,7 @@ install_int_10_handler (void)
       *ptr++ = 0x09;		/* move al,09   ; Finished video init    */
 
       *ptr++ = 0xcd;
-      *ptr++ = 0xe6;		/* int  e6          */
+      *ptr++ = DOS_HELPER_INT;		/* int  e6          */
 
       *ptr++ = 0x58;		/* pop ax           */
       *ptr++ = 0xfb;		/* start interrupts STI  */
