@@ -6,8 +6,12 @@
 #ifndef EMU_H
 #define EMU_H
 
+#include <features.h>
 #include <sys/types.h>
 #include <signal.h> 
+#if __GLIBC__ > 1
+#include <sigcontext.h>
+#endif
 #include "config.h"
 #include "types.h"
 #include "extern.h"
@@ -55,7 +59,18 @@ EXTERN int terminal_fd INIT(-1);
 EXTERN int running_kversion INIT(0);
 
 /* set to one if runing setuid as root */
+#if 1
+#define i_am_root 1  /* neadless to have it variable, it will be allways 1
+                      * If dosemu isn't suid root, it will terminate
+                      */
+#else
 EXTERN int i_am_root INIT(0);
+#endif
+
+/* set, if dosemu was started from a 'root login',
+ * unset, if dosemu was started from a 'user login' (running suid root)
+ */
+EXTERN int under_root_login INIT(0);
 
 EXTERN char *cstack[16384];
 
@@ -255,7 +270,7 @@ extern FILE *dbg_fd;
 
      int set_ioperm(int, int, int);
 
-     EXTERN struct debug_flags d;
+     EXTERN struct debug_flags d INIT({0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0});
      EXTERN u_char in_sighandler, in_ioctl;
 /* one-entry queue ;-( for ioctl's */
 EXTERN struct ioctlq iq INIT({0, 0, 0, 0}); 
@@ -291,6 +306,8 @@ EXTERN struct ioctlq curi INIT({0, 0, 0, 0});
 	  errno, strerror(errno), __FILE__, __LINE__, #sc); \
   s_tmp; })
 
+#define SILENT_DOS_SYSCALL(sc) sc
+
 #if 0
 #define RPT_SYSCALL(sc) ({ int s_tmp, s_err; \
    do { \
@@ -428,6 +445,7 @@ EXTERN struct ioctlq curi INIT({0, 0, 0, 0});
        unsigned char *num_table;
        unsigned short detach;
        unsigned char *debugout;
+       unsigned char *pre_stroke;  /* pointer to keyboard pre strokes */
 
        /* Lock File business */
        char *tty_lockdir;	/* The Lock directory  */
@@ -473,6 +491,9 @@ config_t;
 #define KEYB_PO               20
 #define KEYB_IT               21
 #define KEYB_SW		      22
+#define KEYB_HU		      23
+#define KEYB_HU_CWI	      24
+#define KEYB_HU_LATIN2	      25
 /*
  * Right now, dosemu only supports two serial ports.
  */
@@ -595,6 +616,9 @@ EXTERN void sigio(int, int, struct sigcontext *);
 			sigaction(sig, &sa, NULL);
 #endif
 #ifdef __linux__
+#ifdef __GLIBC__
+#define SignalHandler __sighandler_t
+#endif
 #define NEWSETQSIG(sig, fun)	sa.sa_handler = (__sighandler_t)fun; \
 			/* Point to the top of the stack, minus 4 \
 			   just in case, and make it aligned  */ \
